(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     61758,       1209]
NotebookOptionsPosition[     59608,       1150]
NotebookOutlinePosition[     60031,       1166]
CellTagsIndexPosition[     59988,       1163]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["LATTICEEASY NOTEBOOK: Scale Factor", "Title",
 CellChangeTimes->{
  3.717367577243697*^9},ExpressionUUID->"b43c92e5-bd8c-4f01-986b-\
d481d341554e"],

Cell["\<\
This notebook produces plots of the scale factor and its derivatives from the \
output of the latticeeasy program.
Last modified: 10/18/17\
\>", "Text",
 CellChangeTimes->{{3.7173675730607347`*^9, 3.7173675851588154`*^9}, {
  3.717367843488717*^9, 
  3.7173678486329985`*^9}},ExpressionUUID->"d286c499-e4b0-4f87-9ae0-\
e7bfb9a91ecd"],

Cell["Clear all variables to avoid naming conflicts.", "Text",
 CellChangeTimes->{{3.7173593539180403`*^9, 
  3.717359364375927*^9}},ExpressionUUID->"21f5cbca-df56-4029-a31c-\
ee0d88daaf18"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.7173584246909575`*^9, 
  3.7173584246929617`*^9}},ExpressionUUID->"36cdbadd-7bea-4458-8a9b-\
fd2b5e59cf92"],

Cell[CellGroupData[{

Cell["\<\
PARAMETERS : Set parameters for where to read data and what to plot\
\>", "Section",
 CellChangeTimes->{{3.717367603577123*^9, 
  3.7173676092259045`*^9}},ExpressionUUID->"c137df40-26e9-41ba-9c99-\
a46fcdc898cf"],

Cell["\<\
The run variables are
  dir - The directory where the files are stored
  ext - The extension of the data files
  skip - Number of points to skip between each plotted point. Used for making \
plots of large datasets
  name - Used to label the run in combined plots\
\>", "Text",
 CellChangeTimes->{{3.7173676161890335`*^9, 
  3.717367617682205*^9}},ExpressionUUID->"144394d6-8155-4c91-96e6-\
db0ba03a28db"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"run", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"dir", "[", "run", "]"}], "=", 
   "\"\<c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\>\""}], ";", 
  RowBox[{
   RowBox[{"ext", "[", "run", "]"}], "=", "\"\<_0.dat\>\""}], ";", 
  RowBox[{
   RowBox[{"skip", "[", "run", "]"}], "=", "1"}], ";", 
  RowBox[{"run", "++"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"numruns", "=", "run"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4220313683497725`*^9, 3.423922566927244*^9, {3.446980694622232*^9, 
   3.446980701118235*^9}, 
   3.717367633461635*^9},ExpressionUUID->"7126355d-8523-4bd0-84f2-\
62f6ee2921c1"]
}, Closed]],

Cell[CellGroupData[{

Cell["DATA : Read in data and make tables", "Section",
 CellChangeTimes->{{3.71736764882063*^9, 
  3.7173676537692604`*^9}},ExpressionUUID->"31bc25f3-e596-40db-ba64-\
8fab7b3f9d79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"intablesf", "[", "run", "]"}], "=", 
      RowBox[{"ReadList", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"dir", "[", "run", "]"}], "<>", "\"\<sf\>\"", "<>", 
         RowBox[{"ext", "[", "run", "]"}]}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{"Real", ",", 
          RowBox[{"{", "4", "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"numtimes", "[", "run", "]"}], "=", 
      RowBox[{"Count", "[", 
       RowBox[{
        RowBox[{"intablesf", "[", "run", "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{"_Real", ",", 
          RowBox[{"{", "4", "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sftable", "[", "run", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"intablesf", "[", "run", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"intablesf", "[", "run", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"numtimes", "[", "run", "]"}], ",", 
          RowBox[{"skip", "[", "run", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"hbtable", "[", "run", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"intablesf", "[", "run", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"intablesf", "[", "run", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"numtimes", "[", "run", "]"}], ",", 
          RowBox[{"skip", "[", "run", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a2dtable", "[", "run", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"intablesf", "[", "run", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"intablesf", "[", "run", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "4"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"numtimes", "[", "run", "]"}], ",", 
          RowBox[{"skip", "[", "run", "]"}]}], "}"}]}], "]"}]}], ";"}]}], 
   "\n", "]"}], ";"}]], "Input",ExpressionUUID->"77c70938-2e2d-4218-9e08-\
1972ce24815c"]
}, Closed]],

Cell[CellGroupData[{

Cell["PLOTS : Make plots of the scale factor and its derivatives", "Section",
 CellChangeTimes->{{3.7173676662555065`*^9, 
  3.7173676730259066`*^9}},ExpressionUUID->"9461b374-9091-4cf7-84fa-\
b1fe3986f35e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sfplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"sftable", "[", "run", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"run", ",", "0", ",", 
       RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4220314973835*^9, 3.422031505180525*^9}, {
  3.4220315752287445`*^9, 3.422031606010586*^9}, {3.717367685447316*^9, 
  3.7173676859864206`*^9}},ExpressionUUID->"7ba2d804-f225-4a8a-914c-\
226a28069679"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmmdUk1nbhUNRsWNHWhJ679IhO/ROSCEhAkmAAI6NceyFBHUAO46jYiPB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      
      "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {0, 107.887039}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4220314288040586`*^9, 3.422031507821201*^9, 
  3.423922573008602*^9, 3.424184392440072*^9, 3.446980704790725*^9, 
  3.717367688911189*^9, 
  3.717367837229436*^9},ExpressionUUID->"6041f36d-977c-4715-9049-\
ac63aa7965dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hbplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"hbtable", "[", "run", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"run", ",", "0", ",", 
       RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.422031511243141*^9, 
  3.4220315139619436`*^9}},ExpressionUUID->"212fafa7-815a-4bbf-9010-\
6e58172efdd7"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1mnk4VO/7x8dStElpsWXs+66y3jO3JUtJtuzM2GlDq0pmWmlX2bcZsoZC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      "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {0, 3.2859981050000004`*^-10}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4220314292259417`*^9, 3.422031515915106*^9, 
  3.423922573075456*^9, 3.424184392512159*^9, 3.446980704839846*^9, 
  3.7173676934473968`*^9, 
  3.717367837278469*^9},ExpressionUUID->"133e4c71-54b4-4336-8d03-\
f2ff736c27b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2dplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"a2dtable", "[", "run", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"run", ",", "0", ",", 
        RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4220315180557723`*^9, 3.4220315201495624`*^9}, {
  3.7173677030921063`*^9, 
  3.717367710676324*^9}},ExpressionUUID->"ac12e7ff-334f-4cb1-bff0-\
e7717a65df5c"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], 
     LineBox[{{6.741827684623144, -6.269243725000001*^-19}, {6.750008, 
      1.500774*^-19}, {6.752978089501585, 3.7252008750000008`*^-19}}], 
     LineBox[{{11.215415069089866`, 3.7252008750000008`*^-19}, {
      11.250025, -6.032201*^-19}, {
      11.250838764506117`, -6.269243725000001*^-19}}], 
     LineBox[{{17.474270572665603`, -6.269243725000001*^-19}, {
      17.500019, -3.959936*^-19}, {17.593936889843352`, 
      3.7252008750000008`*^-19}}], 
     LineBox[{{21.910475910110225`, 3.7252008750000008`*^-19}, {
      21.99995, -4.019398*^-20}, {
      22.11604373527324, -6.269243725000001*^-19}}], 
     LineBox[{{24.53504121110379, -6.269243725000001*^-19}, {24.749908, 
      1.606558*^-19}, {24.827439275055305`, 3.7252008750000008`*^-19}}], 
     LineBox[{{25.450366327060593`, 3.7252008750000008`*^-19}, {25.499897, 
      2.481844*^-19}, {25.749893, -6.14835*^-19}, {
      25.754431579823624`, -6.269243725000001*^-19}}], 
     LineBox[{{28.030375459993557`, -6.269243725000001*^-19}, {
      28.249855, -8.614642*^-20}, {28.45469541320828, 
      3.7252008750000008`*^-19}}], 
     LineBox[{{28.97597964783965, 3.7252008750000008`*^-19}, {28.999844, 
      3.426403*^-19}, {29.24984, -2.434401*^-19}, {
      29.43136158159121, -6.269243725000001*^-19}}], 
     LineBox[{{31.49217505717639, -6.269243725000001*^-19}, {
      31.499805, -6.187602*^-19}, {31.749802, -2.048257*^-19}, {31.9998, 
      2.353612*^-19}, {32.145273786816894`, 3.7252008750000008`*^-19}}], 
     LineBox[{{32.45168765599224, 3.7252008750000008`*^-19}, {32.49979, 
      3.490409*^-19}, {32.749786, -3.976372*^-20}, {
      32.999783, -4.55371*^-19}, {
      33.15638576814444, -6.269243725000001*^-19}}], 
     LineBox[{{34.85301269808412, -6.269243725000001*^-19}, {
      34.999752, -5.317873*^-19}, {35.249748, -2.545017*^-19}, {35.499744, 
      8.262951*^-20}, {35.749741, 3.229382*^-19}, {35.999737, 
      3.154945*^-19}, {36.249733, 6.947518*^-20}, {
      36.499729, -2.528963*^-19}, {36.749725, -4.965744*^-19}, {
      36.999722, -6.153664*^-19}, {
      37.1015035853882, -6.269243725000001*^-19}}], LineBox[CompressedData["
1:eJwtmmdQE+/XhgOiFAERFZSW0KQpRVHBADlI76F3EkKLioq9k2ADK/izYQUR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      "]], 
     LineBox[{{3.0868700222423104`, -6.269243725000001*^-19}, {
      3.089468734218402, 3.7252008750000008`*^-19}}], 
     LineBox[{{3.9635468694642975`, 3.7252008750000008`*^-19}, {
      3.966704446395613, -6.269243725000001*^-19}}], 
     LineBox[{{7.616390544778997, 3.7252008750000008`*^-19}, {
      7.628949955397699, -6.269243725000001*^-19}}], 
     LineBox[{{10.348765401351143`, -6.269243725000001*^-19}, {
      10.378687449058173`, 3.7252008750000008`*^-19}}], 
     LineBox[{{13.919358037677988`, -6.269243725000001*^-19}, {
      13.979386043569953`, 3.7252008750000008`*^-19}}], 
     LineBox[{{14.799673136821696`, 3.7252008750000008`*^-19}, {
      14.86598862784292, -6.269243725000001*^-19}}], 
     LineBox[{{18.361123763308317`, 3.7252008750000008`*^-19}, {
      18.48201865187295, -6.269243725000001*^-19}}], 
     LineBox[{{21.01566415693486, -6.269243725000001*^-19}, {
      21.198458612946197`, 
      3.7252008750000008`*^-19}}]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-6.269243725000001*^-19, 
    3.7252008750000008`*^-19}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.422031429444696*^9, 3.422031522055849*^9, 3.423922573134009*^9, 
   3.424184392567042*^9, 3.446980704894833*^9, {3.7173676979413033`*^9, 
   3.7173677113553305`*^9}, 
   3.717367837330511*^9},ExpressionUUID->"3becbfef-e47f-444c-ad58-\
fc0d99e98647"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1256, 893},
WindowMargins->{{Automatic, 118}, {Automatic, 64}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 153, 3, 101, "Title", "ExpressionUUID" -> \
"b43c92e5-bd8c-4f01-986b-d481d341554e"],
Cell[723, 27, 343, 8, 49, "Text", "ExpressionUUID" -> \
"d286c499-e4b0-4f87-9ae0-e7bfb9a91ecd"],
Cell[1069, 37, 190, 3, 30, "Text", "ExpressionUUID" -> \
"21f5cbca-df56-4029-a31c-ee0d88daaf18"],
Cell[1262, 42, 206, 4, 30, "Input", "ExpressionUUID" -> \
"36cdbadd-7bea-4458-8a9b-fd2b5e59cf92"],
Cell[CellGroupData[{
Cell[1493, 50, 222, 5, 70, "Section", "ExpressionUUID" -> \
"c137df40-26e9-41ba-9c99-a46fcdc898cf"],
Cell[1718, 57, 415, 10, 106, "Text", "ExpressionUUID" -> \
"144394d6-8155-4c91-96e6-db0ba03a28db"],
Cell[2136, 69, 686, 19, 69, "Input", "ExpressionUUID" -> \
"7126355d-8523-4bd0-84f2-62f6ee2921c1"]
}, Closed]],
Cell[CellGroupData[{
Cell[2859, 93, 181, 3, 56, "Section", "ExpressionUUID" -> \
"31bc25f3-e596-40db-ba64-8fab7b3f9d79"],
Cell[3043, 98, 3061, 85, 145, "Input", "ExpressionUUID" -> \
"77c70938-2e2d-4218-9e08-1972ce24815c"]
}, Closed]],
Cell[CellGroupData[{
Cell[6141, 188, 207, 3, 56, "Section", "ExpressionUUID" -> \
"9461b374-9091-4cf7-84fa-b1fe3986f35e"],
Cell[CellGroupData[{
Cell[6373, 195, 508, 12, 30, "Input", "ExpressionUUID" -> \
"7ba2d804-f225-4a8a-914c-226a28069679"],
Cell[6884, 209, 16278, 283, 240, "Output", "ExpressionUUID" -> \
"6041f36d-977c-4715-9049-ac63aa7965dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23199, 497, 413, 11, 30, "Input", "ExpressionUUID" -> \
"212fafa7-815a-4bbf-9010-6e58172efdd7"],
Cell[23615, 510, 17485, 302, 219, "Output", "ExpressionUUID" -> \
"133e4c71-54b4-4336-8d03-f2ff736c27b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41137, 817, 537, 14, 30, "Input", "ExpressionUUID" -> \
"ac12e7ff-334f-4cb1-bff0-e7717a65df5c"],
Cell[41677, 833, 17891, 312, 209, "Output", "ExpressionUUID" -> \
"3becbfef-e47f-444c-ad58-fc0d99e98647"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

